@@ -28,6 +28,10 @@
 #define ROVOL	1
 #define BACKVOL	2
 
+#ifdef DEBUG
+extern void afsi_log(char *pattern, ...);
+#endif
+
 unsigned int cm_mountRootGen = 0;
 
 char cm_sysName[100];
@@ -955,15 +959,16 @@ long cm_Lookup(cm_scache_t *dscp, char *namep, long flags, cm_user_t *userp,
 {
 	long code;
 	int dnlcHit = 1;	/* did we hit in the dnlc? yes, we did */
-        cm_scache_t *tscp = NULL;
-        cm_scache_t *mountedScp;
-        cm_lookupSearch_t rock;
-        char tname[256];
+    cm_scache_t *tscp = NULL;
+    cm_scache_t *mountedScp;
+    cm_lookupSearch_t rock;
+    char tname[256];
+	int getroot;
 
 	if (dscp->fid.vnode == 1 && dscp->fid.unique == 1
-	    && strcmp(namep, "..") == 0) {
+         && strcmp(namep, "..") == 0) {
 		if (dscp->dotdotFidp == (cm_fid_t *)NULL
-		    || dscp->dotdotFidp->volume == 0)
+             || dscp->dotdotFidp->volume == 0)
 			return CM_ERROR_NOSUCHVOLUME;
 		rock.fid = *dscp->dotdotFidp;
 		goto haveFid;
@@ -971,83 +976,100 @@ long cm_Lookup(cm_scache_t *dscp, char *namep, long flags, cm_user_t *userp,
 
 	if (cm_ExpandSysName(namep, tname, sizeof(tname))) {
 		namep = tname;
-        }
+    }
 	memset(&rock, 0, sizeof(rock));
-        rock.fid.cell = dscp->fid.cell;
-        rock.fid.volume = dscp->fid.volume;
-        rock.searchNamep = namep;
-        rock.caseFold = (flags & CM_FLAG_CASEFOLD);
+    rock.fid.cell = dscp->fid.cell;
+    rock.fid.volume = dscp->fid.volume;
+    rock.searchNamep = namep;
+    rock.caseFold = (flags & CM_FLAG_CASEFOLD);
 	rock.hasTilde = ((strchr(namep, '~') != NULL) ? 1 : 0);
 
 	/* If NOMOUNTCHASE, bypass DNLC by passing NULL scp pointer */
 	code = cm_ApplyDir(dscp, cm_LookupSearchProc, &rock, NULL, userp, reqp,
-			   (flags & CM_FLAG_NOMOUNTCHASE) ? NULL : &tscp);
+                       (flags & CM_FLAG_NOMOUNTCHASE) ? NULL : &tscp);
 
 	/* code == 0 means we fell off the end of the dir, while stopnow means
-         * that we stopped early, probably because we found the entry we're
+     * that we stopped early, probably because we found the entry we're
 	 * looking for.  Any other non-zero code is an error.
-         */
-        if (code && code != CM_ERROR_STOPNOW) return code;
-        
-        if (!rock.found)
-		if (flags & CM_FLAG_CHECKPATH)
-			return CM_ERROR_NOSUCHPATH;
-		else
-			return CM_ERROR_NOSUCHFILE;
-        
+     */
+    if (code && code != CM_ERROR_STOPNOW) 
+        return code;
+
+	getroot = (dscp==cm_rootSCachep) ;
+    if (!rock.found) {
+        if (!cm_freelanceEnabled || !getroot) {
+            if (flags & CM_FLAG_CHECKPATH)
+                return CM_ERROR_NOSUCHPATH;
+            else
+                return CM_ERROR_NOSUCHFILE;
+        }
+        else {  /* nonexistent dir on freelance root, so add it */
+            code = cm_FreelanceAddMount(namep, namep, "root.cell.",
+					&rock.fid);
+            if (code < 0) {   /* add mount point failed, so give up */
+                if (flags & CM_FLAG_CHECKPATH)
+                    return CM_ERROR_NOSUCHPATH;
+                else
+                    return CM_ERROR_NOSUCHFILE;
+            }
+            tscp = NULL;   /* to force call of cm_GetSCache */
+        }
+	}
+
 haveFid:       
 	if ( !tscp )    /* we did not find it in the dnlc */
 	{
 		dnlcHit = 0;	
-        	code = cm_GetSCache(&rock.fid, &tscp, userp, reqp);
-        	if (code) return code;
+        code = cm_GetSCache(&rock.fid, &tscp, userp, reqp);
+        if (code) 
+            return code;
 	}
-        /* tscp is now held */
-        
+    /* tscp is now held */
+
 	lock_ObtainMutex(&tscp->mx);
 	code = cm_SyncOp(tscp, NULL, userp, reqp, 0,
-        	CM_SCACHESYNC_GETSTATUS | CM_SCACHESYNC_NEEDCALLBACK);
-        if (code) {
+                      CM_SCACHESYNC_GETSTATUS | CM_SCACHESYNC_NEEDCALLBACK);
+    if (code) { 
 		lock_ReleaseMutex(&tscp->mx);
 		cm_ReleaseSCache(tscp);
-        	return code;
+        return code;
 	}
-        /* tscp is now locked */
+    /* tscp is now locked */
 
-        if (!(flags & CM_FLAG_NOMOUNTCHASE)
+    if (!(flags & CM_FLAG_NOMOUNTCHASE)
 	      && tscp->fileType == CM_SCACHETYPE_MOUNTPOINT) {
 		/* mount points are funny: they have a volume name to mount
-                 * the root of.
-                 */
+         * the root of.
+         */
 		code = cm_ReadMountPoint(tscp, userp, reqp);
-                if (code == 0)
+        if (code == 0)
 			code = cm_FollowMountPoint(tscp, dscp, userp, reqp,
-						   &mountedScp);
+                                        &mountedScp);
 		lock_ReleaseMutex(&tscp->mx);
 		cm_ReleaseSCache(tscp);
 		if (code) {
-                        return code;
-                }
-                tscp = mountedScp;
+            return code;
         }
+        tscp = mountedScp;
+    }
 	else {
 		lock_ReleaseMutex(&tscp->mx);
 	}
 
 	/* copy back pointer */
-        *outpScpp = tscp;
+    *outpScpp = tscp;
 
 	/* insert scache in dnlc */
 	if ( !dnlcHit && !(flags & CM_FLAG_NOMOUNTCHASE) ) {
 	    /* lock the directory entry to prevent racing callback revokes */
 	    lock_ObtainMutex(&dscp->mx);
 	    if ( dscp->cbServerp && dscp->cbExpires )
-		cm_dnlcEnter(dscp, namep, tscp);
+            cm_dnlcEnter(dscp, namep, tscp);
 	    lock_ReleaseMutex(&dscp->mx);
 	}
 
 	/* and return */
-        return 0;
+    return 0;
 }
 
 long cm_Unlink(cm_scache_t *dscp, char *namep, cm_user_t *userp, cm_req_t *reqp)
@@ -1190,9 +1212,17 @@ long cm_AssembleLink(cm_scache_t *linkScp, char *pathSuffixp,
                 *newRootScpp = cm_rootSCachep;
                 cm_HoldSCache(cm_rootSCachep);
         } else if (*linkp == '\\' || *linkp == '/') {
+	  /* formerly, this was considered to be from the AFS root,
+	     but this seems to create problems.  instead, we will just
+	     reject the link */
+#if 0
 		strcpy(tsp->data, linkp+1);
                 *newRootScpp = cm_rootSCachep;
                 cm_HoldSCache(cm_rootSCachep);
+#else
+		code = CM_ERROR_NOSUCHPATH;
+		goto done;
+#endif
         }
         else {
 		/* a relative link */
@@ -1244,140 +1274,140 @@ long cm_NameI(cm_scache_t *rootSCachep, char *pathp, long flags,
         cm_HoldSCache(tscp);
         symlinkCount = 0;
         while (1) {
-		tc = *tp++;
+            tc = *tp++;
 		
-                /* map Unix slashes into DOS ones so we can interpret Unix
-		 * symlinks properly
-                 */
-                if (tc == '/') tc = '\\';
-		
-                if (!haveComponent) {
+            /* map Unix slashes into DOS ones so we can interpret Unix
+             * symlinks properly
+             */
+            if (tc == '/') tc = '\\';
+
+            if (!haveComponent) {
 			if (tc == '\\') continue;
-                        else if (tc == 0) {
+            else if (tc == 0) {
 				if (phase == 1) {
 					phase = 2;
 					tp = pathp;
 					continue;
 				}
-                        	code = 0;
-                                break;
-                        }
-                        else {
+                code = 0;
+                break;
+            }
+            else {
 				haveComponent = 1;
-                                cp = component;
-                                *cp++ = tc;
+                cp = component;
+                *cp++ = tc;
+            }
+            }
+            else {
+                /* we have a component here */
+                if (tc == 0 || tc == '\\') {
+                    /* end of the component; we're at the last
+                     * component if tc == 0.  However, if the last
+                     * is a symlink, we have more to do.
+                     */
+                    *cp++ = 0;	/* add null termination */
+                    extraFlag = 0;
+                    if ((flags & CM_FLAG_DIRSEARCH) && tc == 0)
+                        extraFlag = CM_FLAG_NOMOUNTCHASE;
+                    code = cm_Lookup(tscp, component,
+                                      flags | extraFlag,
+                                      userp, reqp, &nscp);
+
+                    if (code) {
+                        cm_ReleaseSCache(tscp);
+                        if (psp) cm_FreeSpace(psp);
+                        return code;
+                    }
+                    haveComponent = 0;	/* component done */
+                    dirScp = tscp;		/* for some symlinks */
+                    tscp = nscp;	/* already held */
+                    if (tc == 0 && !(flags & CM_FLAG_FOLLOW) && phase == 2) {
+                        code = 0;
+                        cm_ReleaseSCache(dirScp);
+                        break;
+                    }
+
+                    /* now, if tscp is a symlink, we should follow
+                     * it and assemble the path again.
+                     */
+                    lock_ObtainMutex(&tscp->mx);
+                    code = cm_SyncOp(tscp, NULL, userp, reqp, 0,
+                                      CM_SCACHESYNC_GETSTATUS
+                                      | CM_SCACHESYNC_NEEDCALLBACK);
+                    if (code) {
+                        lock_ReleaseMutex(&tscp->mx);
+                        cm_ReleaseSCache(tscp);
+                        cm_ReleaseSCache(dirScp);
+                        break;
+                    }
+                    if (tscp->fileType == CM_SCACHETYPE_SYMLINK) {
+                        /* this is a symlink; assemble a new buffer */
+                        lock_ReleaseMutex(&tscp->mx);
+                        if (symlinkCount++ >= 16) {
+                            cm_ReleaseSCache(tscp);
+                            cm_ReleaseSCache(dirScp);
+                            if (psp) cm_FreeSpace(psp);
+                            return CM_ERROR_TOOBIG;
                         }
-                }
-		else {
-			/* we have a component here */
-                        if (tc == 0 || tc == '\\') {
-				/* end of the component; we're at the last
-				 * component if tc == 0.  However, if the last
-				 * is a symlink, we have more to do.
-                                 */
-                                *cp++ = 0;	/* add null termination */
-				extraFlag = 0;
-				if ((flags & CM_FLAG_DIRSEARCH) && tc == 0)
-					extraFlag = CM_FLAG_NOMOUNTCHASE;
-                                code = cm_Lookup(tscp, component,
-					flags | extraFlag,
-					userp, reqp, &nscp);
-                                if (code) {
-					cm_ReleaseSCache(tscp);
-                                        if (psp) cm_FreeSpace(psp);
-                                        return code;
-                                }
-                                haveComponent = 0;	/* component done */
-                                dirScp = tscp;		/* for some symlinks */
-                                tscp = nscp;	/* already held */
-                                if (tc == 0 && !(flags & CM_FLAG_FOLLOW) && phase == 2) {
-					code = 0;
-                                        cm_ReleaseSCache(dirScp);
-                                	break;
-				}
-                                
-                                /* now, if tscp is a symlink, we should follow
-				 * it and assemble the path again.
-                                 */
-				lock_ObtainMutex(&tscp->mx);
-				code = cm_SyncOp(tscp, NULL, userp, reqp, 0,
-			        	CM_SCACHESYNC_GETSTATUS
-					 | CM_SCACHESYNC_NEEDCALLBACK);
-                                if (code) {
-					lock_ReleaseMutex(&tscp->mx);
-					cm_ReleaseSCache(tscp);
-                                        cm_ReleaseSCache(dirScp);
-                                        break;
-                                }
-                                if (tscp->fileType == CM_SCACHETYPE_SYMLINK) {
-					/* this is a symlink; assemble a new buffer */
-					lock_ReleaseMutex(&tscp->mx);
-                                        if (symlinkCount++ >= 16) {
-						cm_ReleaseSCache(tscp);
-                                                cm_ReleaseSCache(dirScp);
-						if (psp) cm_FreeSpace(psp);
-                                                return CM_ERROR_TOOBIG;
-                                        }
-                                        if (tc == 0) restp = "";
-                                        else restp = tp;
-                                        code = cm_AssembleLink(tscp, restp,
-						&linkScp, &tempsp, userp, reqp);
-                                        if (code) {
-						/* something went wrong */
-						cm_ReleaseSCache(tscp);
-                                                cm_ReleaseSCache(dirScp);
-	                                        break;
-                                        }
-                                        
-                                        /* otherwise, tempsp has the new path,
-					 * and linkScp is the new root from
-					 * which to interpret that path.
-					 * Continue with the namei processing,
-					 * also doing the bookkeeping for the
-					 * space allocation and tracking the
-                                         * vnode reference counts.
-                                         */
-					if (psp) cm_FreeSpace(psp);
-					psp = tempsp;
-                                        tp = psp->data;
-                                        cm_ReleaseSCache(tscp);
-                                        tscp = linkScp;	/* already held
-							 * by AssembleLink */
-                                        /* now, if linkScp is null, that's
-					 * AssembleLink's way of telling us that
-					 * the sym link is relative to the dir
-					 * containing the link.  We have a ref
-					 * to it in dirScp, and we hold it now
-					 * and reuse it as the new spot in the
-					 * dir hierarchy.
-                                         */
-                                        if (tscp == NULL) {
-						cm_HoldSCache(dirScp);
-                                                tscp = dirScp;
-                                        }
-                                }	/* if we have a sym link */
-                                else {
-					/* not a symlink, we may be done */
-                                	lock_ReleaseMutex(&tscp->mx);
-                                        if (tc == 0) {
-						if (phase == 1) {
-							phase = 2;
-							tp = pathp;
-							continue;
-						}
-						cm_ReleaseSCache(dirScp);
-                                                code = 0;
-                                                break;
-                                        }
-				}
-                                cm_ReleaseSCache(dirScp);
-                        } /* end of a component */
-                        else *cp++ = tc;
-                } /* we have a component */
-        }	/* big while loop over all components */
+                        if (tc == 0) restp = "";
+                        else restp = tp;
+                        code = cm_AssembleLink(tscp, restp, &linkScp, &tempsp, userp, reqp);
+                        if (code) {
+                            /* something went wrong */
+                            cm_ReleaseSCache(tscp);
+                            cm_ReleaseSCache(dirScp);
+                            break;
+                        }
+
+                        /* otherwise, tempsp has the new path,
+                         * and linkScp is the new root from
+                         * which to interpret that path.
+                         * Continue with the namei processing,
+                         * also doing the bookkeeping for the
+                         * space allocation and tracking the
+                         * vnode reference counts.
+                         */
+                        if (psp) cm_FreeSpace(psp);
+                        psp = tempsp;
+                        tp = psp->data;
+                        cm_ReleaseSCache(tscp);
+                        tscp = linkScp;	/* already held
+                                         * by AssembleLink */
+                        /* now, if linkScp is null, that's
+                         * AssembleLink's way of telling us that
+                         * the sym link is relative to the dir
+                         * containing the link.  We have a ref
+                         * to it in dirScp, and we hold it now
+                         * and reuse it as the new spot in the
+                         * dir hierarchy.
+                         */
+                        if (tscp == NULL) {
+                            cm_HoldSCache(dirScp);
+                            tscp = dirScp;
+                        }
+                    }	/* if we have a sym link */
+                    else {
+                        /* not a symlink, we may be done */
+                        lock_ReleaseMutex(&tscp->mx);
+                        if (tc == 0) {
+                            if (phase == 1) {
+                                phase = 2;
+                                tp = pathp;
+                                continue;
+                            }
+                            cm_ReleaseSCache(dirScp);
+                            code = 0;
+                            break;
+                        }
+                    }
+                    cm_ReleaseSCache(dirScp);
+                } /* end of a component */
+                else *cp++ = tc;
+            } /* we have a component */
+        } /* big while loop over all components */
 
 	/* already held */
-        if (psp) cm_FreeSpace(psp);
+    if (psp) cm_FreeSpace(psp);
 	if (code == 0) *outScpp = tscp;
         return code;
 }
