@@ -15,7 +15,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_module.c,v 1.41 2003/07/29 02:00:47 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_module.c,v 1.43 2004/02/03 06:23:34 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -86,12 +86,16 @@ static void **ia32_sys_call_table;
 #endif
 
 static void *ia32_ni_syscall = 0;
-asmlinkage long (*sys32_setgroupsp) (int gidsetsize, old_gid_t * grouplist);
+asmlinkage long (*sys32_setgroupsp) (int gidsetsize, u16 * grouplist);
 #if defined(__NR_ia32_setgroups32)
 asmlinkage long (*sys32_setgroups32p) (int gidsetsize, gid_t * grouplist);
 #endif /* __NR_ia32_setgroups32 */
 #endif /* AFS_AMD64_LINUX20_ENV */
 
+#ifdef AFS_PPC64_LINUX20_ENV
+asmlinkage long (*sys32_setgroupsp)(int gidsetsize, gid_t *grouplist);
+#endif /* AFS_AMD64_LINUX20_ENV */
+
 #ifdef AFS_SPARC64_LINUX20_ENV
 static unsigned int afs_ni_syscall32 = 0;
 asmlinkage int (*sys32_setgroupsp) (int gidsetsize,
@@ -158,6 +162,12 @@ asmlinkage int (*sys_setgroups32p) (int gidsetsize,
 #define SYSCALL2POINTER (void *)
 #endif
 
+#ifdef AFS_PPC64_LINUX20_ENV
+extern void *set_afs_syscall(void*);
+extern void *set_afs_xsetgroups_syscall(void*);
+extern void *set_afs_xsetgroups_syscall32(void*);
+#endif
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
 int __init
 afs_init(void)
@@ -167,7 +177,7 @@ init_module(void)
 #endif
 {
 #if defined(AFS_IA64_LINUX20_ENV)
-    unsigned long kernel_gp;
+    unsigned long kernel_gp = 0;
     static struct fptr sys_settimeofday, sys_setgroups;
 #endif
     extern int afs_syscall();
@@ -175,7 +185,7 @@ init_module(void)
 #if defined(__NR_setgroups32)
     extern int afs_xsetgroups32();
 #endif /* __NR_setgroups32 */
-#if defined(AFS_SPARC64_LINUX20_ENV) || defined (AFS_AMD64_LINUX20_ENV)
+#if defined(AFS_SPARC64_LINUX20_ENV) || defined (AFS_AMD64_LINUX20_ENV) || defined(AFS_PPC64_LINUX20_ENV)
     extern int afs32_xsetgroups();
 #if (defined(__NR_setgroups32) && defined(AFS_SPARC64_LINUX20_ENV))
     extern int afs32_xsetgroups32();
@@ -187,19 +197,19 @@ init_module(void)
 
 #if !defined(EXPORTED_SYS_CALL_TABLE) || (defined(AFS_AMD64_LINUX20_ENV) && !defined(EXPORTED_IA32_SYS_CALL_TABLE))
     unsigned long *ptr;
-    unsigned long offset;
-    unsigned long datalen;
+    unsigned long offset=0;
+    unsigned long datalen=0;
     int ret;
-    unsigned long token;
+    unsigned long token=0;
     char *mod_name;
-    unsigned long mod_start;
-    unsigned long mod_end;
+    unsigned long mod_start=0;
+    unsigned long mod_end=0;
     char *sec_name;
-    unsigned long sec_start;
-    unsigned long sec_end;
+    unsigned long sec_start=0;
+    unsigned long sec_end=0;
     char *sym_name;
-    unsigned long sym_start;
-    unsigned long sym_end;
+    unsigned long sym_start=0;
+    unsigned long sym_end=0;
 #endif /* EXPORTED_SYS_CALL_TABLE */
 
     RWLOCK_INIT(&afs_xosi, "afs_xosi");
@@ -466,6 +476,12 @@ init_module(void)
 #endif /* AFS_AMD64_LINUX20_ENV */
 #endif /* AFS_IA64_LINUX20_ENV */
 
+#ifdef AFS_PPC64_LINUX20_ENV
+    afs_ni_syscall = set_afs_syscall(afs_syscall);
+    sys_setgroupsp = set_afs_xsetgroups_syscall(afs_xsetgroups);
+    sys32_setgroupsp = set_afs_xsetgroups_syscall32(afs32_xsetgroups);
+#endif
+
     osi_sysctl_init();
 
     return 0;
@@ -512,6 +528,11 @@ cleanup_module(void)
 	    POINTER2SYSCALL sys32_setgroups32p;
 #endif
     }
+#endif
+#ifdef AFS_PPC64_LINUX20_ENV
+    set_afs_syscall(afs_ni_syscall);
+    set_afs_xsetgroups_syscall(sys_setgroupsp);
+    set_afs_xsetgroups_syscall32(sys32_setgroupsp);
 #endif
     unregister_filesystem(&afs_file_system);
 
@@ -530,7 +551,7 @@ module_exit(afs_cleanup);
 static long
 get_page_offset(void)
 {
-#if defined(AFS_PPC_LINUX22_ENV) || defined(AFS_SPARC64_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV) || defined(AFS_ALPHA_LINUX20_ENV) || defined(AFS_S390_LINUX22_ENV) || defined(AFS_IA64_LINUX20_ENV) || defined(AFS_PARISC_LINUX24_ENV) || defined(AFS_AMD64_LINUX20_ENV)
+#if defined(AFS_PPC_LINUX22_ENV) || defined(AFS_SPARC64_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV) || defined(AFS_ALPHA_LINUX20_ENV) || defined(AFS_S390_LINUX22_ENV) || defined(AFS_IA64_LINUX20_ENV) || defined(AFS_PARISC_LINUX24_ENV) || defined(AFS_AMD64_LINUX20_ENV) || defined(AFS_PPC64_LINUX20_ENV)
     return PAGE_OFFSET;
 #else
     struct task_struct *p, *q;
